"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var Lint = require("tslint");
var ts = require("typescript");
var Rule = /** @class */ (function (_super) {
    __extends(Rule, _super);
    function Rule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Rule.prototype.apply = function (sourceFile) {
        return this.applyWithWalker(new Walk(sourceFile, this.getOptions()));
    };
    Rule.FAILURE_STRING = 'Async functions with no await are not allowed.';
    return Rule;
}(Lint.Rules.AbstractRule));
exports.Rule = Rule;
var Walk = /** @class */ (function (_super) {
    __extends(Walk, _super);
    function Walk() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Walk.prototype.visitFunctionDeclaration = function (node) {
        this.addFailureIfAsyncFunctionHasNoAwait(node);
        _super.prototype.visitFunctionDeclaration.call(this, node);
    };
    Walk.prototype.visitArrowFunction = function (node) {
        this.addFailureIfAsyncFunctionHasNoAwait(node);
        _super.prototype.visitArrowFunction.call(this, node);
    };
    Walk.prototype.visitMethodDeclaration = function (node) {
        this.addFailureIfAsyncFunctionHasNoAwait(node);
        _super.prototype.visitMethodDeclaration.call(this, node);
    };
    Walk.prototype.isAsyncFunction = function (node) {
        return this.getAsyncModifier(node) !== undefined;
    };
    Walk.prototype.getAsyncModifier = function (node) {
        if (node.modifiers !== undefined) {
            return node.modifiers.find(function (modifier) { return modifier.kind === ts.SyntaxKind.AsyncKeyword; });
        }
        return;
    };
    Walk.prototype.isAwait = function (node) {
        return node.kind === ts.SyntaxKind.AwaitKeyword;
    };
    Walk.prototype.isReturn = function (node) {
        return node.kind === ts.SyntaxKind.ReturnKeyword;
    };
    Walk.prototype.functionBlockHasAwait = function (node) {
        var _this = this;
        if (this.isAwait(node)) {
            return true;
        }
        // tslint:disable-next-line:no-unsafe-any
        if (node.kind === ts.SyntaxKind.ArrowFunction ||
            node.kind === ts.SyntaxKind.FunctionDeclaration) {
            return false;
        }
        var awaitInChildren = node
            .getChildren()
            .map(function (functionBlockNode) {
            return _this.functionBlockHasAwait(functionBlockNode);
        });
        return awaitInChildren.some(Boolean);
    };
    Walk.prototype.functionBlockHasReturn = function (node) {
        var _this = this;
        if (this.isReturn(node)) {
            return true;
        }
        // tslint:disable-next-line:no-unsafe-any
        if (node.kind === ts.SyntaxKind.ArrowFunction ||
            node.kind === ts.SyntaxKind.FunctionDeclaration) {
            return false;
        }
        var returnInChildren = node
            .getChildren()
            .map(function (functionBlockNode) {
            return _this.functionBlockHasReturn(functionBlockNode);
        });
        return returnInChildren.some(Boolean);
    };
    Walk.prototype.isShortArrowReturn = function (node) {
        return (node.kind === ts.SyntaxKind.ArrowFunction &&
            node.body.kind !== ts.SyntaxKind.Block);
    };
    Walk.prototype.addFailureIfAsyncFunctionHasNoAwait = function (node) {
        if (this.isAsyncFunction(node) &&
            !this.functionBlockHasAwait(node.body) &&
            !this.functionBlockHasReturn(node.body) &&
            !this.isShortArrowReturn(node)) {
            var asyncModifier = this.getAsyncModifier(node);
            if (asyncModifier !== undefined) {
                this.addFailureAt(asyncModifier.getStart(), asyncModifier.getEnd() - asyncModifier.getStart(), Rule.FAILURE_STRING);
            }
        }
    };
    return Walk;
}(Lint.RuleWalker));
//# sourceMappingURL=noAsyncWithoutAwaitRule.js.map