"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var getRule = function (options) {
    if (options === void 0) { options = ['a-package']; }
    return ({
        name: 'no-explicit-import-from-node-module',
        options: options,
    });
};
describe('noExplicitImportFromNodeModule Rule', function () {
    it("should fail when node_module in import path", function () {
        var src = "\n            import * as _ from '../node_modules/a-package';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("'node_modules' shouldn't be in import path");
    });
    it('should not fail on other imports', function () {
        var src = "\n            import * from 'a-package';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(0);
    });
    it('should fail when node_module is last path', function () {
        var src = "\n            import * from './node_modules';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("'node_modules' shouldn't be in import path");
    });
});
//# sourceMappingURL=noExplicitImportFromNodeModuleRule.spec.js.map