"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var getRule = function (options) {
    if (options === void 0) { options = ['a-package']; }
    return ({
        name: 'no-full-package-import',
        options: options,
    });
};
describe('noFullPackgeImport Rule', function () {
    it("should fail when importing a full package that was in the arguments", function () {
        var src = "\n            import * as _ from 'a-package';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("importing the full package 'a-package' is not allowed");
    });
    it("should fail when importing a full package that was in the arguments with suffix dist/src", function () {
        var src = "\n            import * as _ from 'a-package/dist/src';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("importing the full package 'a-package/dist/src' is not allowed");
    });
    it("should fail when importing a full package that was in the arguments with suffix dist/es/src", function () {
        var src = "\n            import * as _ from 'a-package/dist/es/src';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("importing the full package 'a-package/dist/es/src' is not allowed");
    });
    xit("should fail when importing a full package that was in the arguments", function () {
        var src = "\n            import * as _ from \"a-package\";\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe("importing the full package 'a-package' is not allowed");
    });
    it("should not fail when importing a specific file from package", function () {
        var src = "\n            import * as func from 'a-package/func';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(0);
    });
    it("should not fail when importing a full package that is not in the options", function () {
        var src = "\n            import * as func from 'b-package';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule() });
        expect(result.errorCount).toBe(0);
    });
    it("should not fail when importing a specific file from package", function () {
        var src = "\n            import * as func from '@wix/a-package';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: getRule(['@wix/a-package']) });
        expect(result.errorCount).toBe(1);
    });
});
//# sourceMappingURL=noFullPackageImportRule.spec.js.map