"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var rule = 'no-wallaby-file-only';
describe('no-wallaby-file-only rule', function () {
    it('Should not allow the //file.only comment', function () {
        var src = "\n            //file.only\n            var x = 1;\n        ";
        var result = lintRunner_1.helper({ src: src, rule: rule });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe('file.only comments are not allowed');
    });
    it('Should not consider spaces', function () {
        var src = "\n            // file.only\n            var x = 1;\n        ";
        var result = lintRunner_1.helper({ src: src, rule: rule });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe('file.only comments are not allowed');
    });
    it('Should consider asterisks as well', function () {
        var src = "\n            /*file.only*/\n            var x = 1;\n        ";
        var result = lintRunner_1.helper({ src: src, rule: rule });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe('file.only comments are not allowed');
    });
    it('Should consider asterisks as well', function () {
        var src = "\n            var x = function() {\n                /*file.only*/            \n            };\n        ";
        var result = lintRunner_1.helper({ src: src, rule: rule });
        expect(result.errorCount).toBe(1);
        expect(result.failures[0].getFailure()).toBe('file.only comments are not allowed');
    });
    it('Should not raise any issues', function () {
        var src = "\n            var x = '// file.only';\n        ";
        var result = lintRunner_1.helper({ src: src, rule: rule });
        expect(result.errorCount).toBe(0);
    });
});
//# sourceMappingURL=noWallabyFileOnlyRule.spec.js.map