"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var Lint = require("tslint");
var path = require("path");
var utils_1 = require("tslint/lib/utils");
var failureStrings = {
    reactComp: 'react components file names should be PascalCase',
    filesRelatedToReactComp: 'non component files inside the component folder should be either camelCase or PascalCase',
    testkit: 'testkits file names should end with ".testKit"',
    camelCase: 'file names should be camelCase',
    classFiles: 'class files should be PascalCase',
};
function isPascalCased(name) {
    return utils_1.isUpperCase(name[0]) && !name.includes('_') && !name.includes('-');
}
function isLowerCase(str) {
    return str === str.toLowerCase();
}
function isCamelCased(name) {
    return isLowerCase(name[0]) && !name.includes('_') && !name.includes('-');
}
var Rule = /** @class */ (function (_super) {
    __extends(Rule, _super);
    function Rule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Rule.prototype.apply = function (sourceFile) {
        var extname = path.extname(sourceFile.fileName);
        var dirname = path.dirname(sourceFile.fileName);
        var fileName = path.basename(sourceFile.fileName);
        if (extname === '.tsx' && dirname.includes('/components')) {
            if (!isPascalCased(fileName)) {
                return [
                    new Lint.RuleFailure(sourceFile, 0, 0, failureStrings.reactComp, this.ruleName),
                ];
            }
            return;
        }
        if (extname === '.ts' && dirname.includes('/components')) {
            if (!isPascalCased(fileName) && !isCamelCased(fileName)) {
                return [
                    new Lint.RuleFailure(sourceFile, 0, 0, failureStrings.filesRelatedToReactComp, this.ruleName),
                ];
            }
            return;
        }
        if (/testkit\./i.exec(fileName) !== null &&
            !fileName.includes('.testKit.')) {
            return [
                new Lint.RuleFailure(sourceFile, 0, 0, failureStrings.testkit, this.ruleName),
            ];
        }
        var fileNameWithoutExt = fileName.replace(extname, '');
        if (sourceFile.text
            .toLowerCase()
            .includes("class " + fileNameWithoutExt.toLowerCase().replace('.', ''))) {
            if (!isPascalCased(fileName)) {
                return [
                    new Lint.RuleFailure(sourceFile, 0, 0, failureStrings.classFiles, this.ruleName),
                ];
            }
            else {
                return;
            }
        }
        if (fileName.includes('.spec') &&
            (isPascalCased(fileName) || isCamelCased(fileName))) {
            return;
        }
        if (!isCamelCased(fileName)) {
            return [
                new Lint.RuleFailure(sourceFile, 0, 0, failureStrings.camelCase, this.ruleName),
            ];
        }
    };
    return Rule;
}(Lint.Rules.AbstractRule));
exports.Rule = Rule;
//# sourceMappingURL=wixStoresCustomFileNamesRule.js.map