"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lintRunner_1 = require("./lintRunner");
var rule = 'wix-stores-custom-file-names';
var src = '';
describe('wixStoresCustomFileNames Rule', function () {
    it('should enforce PascalCase on react components', function () {
        var result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/components/AA/aaa.tsx' });
        expect(result.failures[0].getFailure()).toEqual('react components file names should be PascalCase');
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/not_components/AA/aaa.tsx' });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/components/AA/aaa.ts' });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: src,
            rule: rule,
            fileName: 'src/components/ProductItem/ProductItem.tsx',
        });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: src,
            rule: rule,
            fileName: '/src/components/RadioOption/RadioOption.spec.ts',
        });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: src,
            rule: rule,
            fileName: '/src/components/RadioOption/radio-otion.spec.ts',
        });
        expect(result.failures[0].getFailure()).toEqual('non component files inside the component folder should be either camelCase or PascalCase');
    });
    it('should enforce ".testKit" on testkits', function () {
        var result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/a.testkit.ts' });
        expect(result.failures[0].getFailure()).toEqual('testkits file names should end with ".testKit"');
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/aTestKit.ts' });
        expect(result.failures[0].getFailure()).toEqual('testkits file names should end with ".testKit"');
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/aTestkit.ts' });
        expect(result.failures[0].getFailure()).toEqual('testkits file names should end with ".testKit"');
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/a.testKit.ts' });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/atestKitblabla.ts' });
        expect(result.failures.length).toEqual(0);
    });
    it('everything else should be camelCase', function () {
        var result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/camelCase.ts' });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/PascalCase.ts' });
        expect(result.failures[0].getFailure()).toEqual('file names should be camelCase');
        result = lintRunner_1.helper({ src: src, rule: rule, fileName: 'src/really_weird_name.ts' });
        expect(result.failures[0].getFailure()).toEqual('file names should be camelCase');
    });
    it('if file exports a class with the name of the file it should be PascalCase', function () {
        var result = lintRunner_1.helper({
            src: 'class Test {};',
            rule: rule,
            fileName: 'src/Test.ts',
        });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: 'class Test {};',
            rule: rule,
            fileName: 'src/test.ts',
        });
        expect(result.failures.length).toEqual(1);
        result = lintRunner_1.helper({
            src: 'class TestDriver {};',
            rule: rule,
            fileName: 'src/Test.driver.ts',
        });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: 'describe("lala", () => {})',
            rule: rule,
            fileName: 'src/Test.spec.ts',
        });
        expect(result.failures.length).toEqual(0);
        result = lintRunner_1.helper({
            src: 'describe("lala", () => {})',
            rule: rule,
            fileName: 'src/test.spec.ts',
        });
        expect(result.failures.length).toEqual(0);
    });
});
//# sourceMappingURL=wixStoresCustomFileNamesRule.spec.js.map